#
# spec file for package python-amqp
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-amqp
Version:        1.4.9
Release:        3.3
Summary:        Low-level AMQP client for Python (fork of amqplib)
License:        LGPL-2.1+
Group:          Development/Languages/Python
Url:            http://github.com/celery/py-amqp
Source:         https://pypi.python.org/packages/source/a/amqp/amqp-%{version}.tar.gz
Source99:       %{name}.changes
# PATCH-FIX-OPENSUSE speilicke@suse.com -- Avoid excessive doc dependencies
Patch0:         amqp-drop-sphinxcontrib-issuetracker-dependency.patch
Patch1:         tune-keepalive-intervals.diff
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Documentation requirements:
BuildRequires:  python-Sphinx
# Test requirements:
BuildRequires:  python-mock
BuildRequires:  python-nose
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-unittest2
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This is a fork of amqplib_ which was originally written by Barry Pederson.
It is maintained by the Celery_ project, and used by kombu as a pure python
alternative when librabbitmq is not available.

This library should be API compatible with librabbitmq.

%prep
%setup -q -n amqp-%{version}
%patch0 -p1
%patch1 -p0

# hack, or sphinx will put today's date into the HTML files
DOCDATE="`date +"%B %e, %Y" -r %{S:99}`"
echo "today = '$DOCDATE'" >> docs/conf.py

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
nosetests

%files
%defattr(-,root,root,-)
%doc Changelog LICENSE README.rst demo build/sphinx/html
%{python_sitelib}/*

%changelog
* Wed Jan 13 2016 antoine.belvire@laposte.net
- Update to 1.4.9:
  * Fix compatibility with Linux/OS X instances where the
    ``ctypes`` module does not exist
- Changes from 1.4.8:
  * ``abstract_channel.wait`` now accepts a float `timeout`
    parameter expressed in seconds
* Thu Dec 10 2015 seife+obs@b1-systems.com
- remove build date from documentation
* Mon Oct  5 2015 mcihar@suse.cz
- Add uniittest2 to BuildRequires for Python 2.6
* Sun Oct  4 2015 tbechtold@suse.com
- update to 1.4.7:
  * Fixed libSystem error on OS X 10.11 (El Capitan)
  * ``channel.basic_publish`` now raises :exc:`amqp.exceptions.NotConfirmed` on
    ``basic.nack``.
  * AMQP timestamps received are now converted from GMT instead of local time
    (Issue #67).
  * Wheel package installation now supported by both Python 2 and Python3.
- Add python-mock as BuildRequires. Needed for tests
* Thu Aug  6 2015 cdenicolo@suse.com
- license update: LGPL-2.1+
  LGPL includes "or later"
* Thu Jan 29 2015 dmueller@suse.com
- replace set_socket_TCP_KEEPALIVE_and_TCP_USER_TIMEOUT.patch
  with tune-keepalive-intervals.diff (bnc#902207)
* Mon Sep 15 2014 tbechtold@suse.com
- update to 1.4.6:
  * Now keeps buffer when socket times out.
  * Adds ``Connection.Transport`` attribute that can be used to specify
    a different transport implementation.
* Mon May  5 2014 dmueller@suse.com
- update to 1.4.5:
  - Can now deserialize more AMQP types.
  - SSL: Workaround for Python SSL bug.
  - ``Transport.__del_`` now handles errors occurring at late interpreter
  shutdown (Issue #36).
  - SSL transport accidentally disconnected after read timeout.
* Thu Mar  6 2014 speilicke@suse.com
- Add amqp-drop-sphinxcontrib-issuetracker-dependency.patch: Avoid
  unnesseary build-time dependencies.
* Thu Feb 20 2014 dmueller@suse.com
- update to 1.4.3:
  - Fixed bug where more data was requested from the socket
    than was actually needed.
  - Heartbeat negotiation would use heartbeat value from server even
    if heartbeat disabled (Issue #31).
* Tue Jan 21 2014 dmueller@suse.com
- update to 1.4.1:
  - Fixed error occurring when heartbeats disabled.
* Tue Jan 14 2014 dmueller@suse.com
- update to 1.4.0:
  - Heartbeat implementation improved (Issue #6).
  - NoneType is now supported in tables and arrays.
  - SSLTransport: Now handles ``ENOENT``.
* Sun Dec  1 2013 oliver.bengs@opensuse.org
- Update to 1.3.3:
  - SSLTransport: Now keeps read buffer if an exception is raised
  - Message.channel is now a channel object (not the channel id)
  - Now sets ``Message.channel`` on delivery
  - New option to wait for publish confirmations
  - ``queue_declare`` now returns named tuple of type
  - Contents of ``Channel.returned_messages`` is now named tuples.
  - Sockets now set to close on exec using the ``FD_CLOEXEC`` flag
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Apr 30 2013 speilicke@suse.com
- Run testsuite
* Mon Feb 11 2013 saschpe@suse.de
- Add Python3 support
- Build HTML documentation
- Install LICENSE, README.rst
* Mon Nov 12 2012 alexandre@exatati.com.br
- Update to 1.2.0:
  - New exception hierarchy:
  - amqp.AMQPError
  - amqp.ConnectionError
  - amqp.RecoverableConnectionError
  - amqp.ConsumerCancelled
  - amqp.ConnectionForced
  - amqp.ResourceError
  - IrrecoverableConnectionError
  - amqp.ChannelNotOpen
  - amqp.FrameError
  - amqp.FrameSyntaxError
  - amqp.InvalidCommand
  - amqp.InvalidPath
  - amqp.NotAllowed
  - amqp.UnexpectedFrame
  - amqp.AMQPNotImplementedError
  - amqp.InternalError
  - amqp.ChannelError
  - RecoverableChannelError
  - amqp.ContentTooLarge
  - amqp.NoConsumers
  - amqp.ResourceLocked
  - IrrecoverableChannelError
  - amqp.AccessRefused
  - amqp.NotFound
  - amqp.PreconditionFailed
* Thu Nov  8 2012 alexandre@exatati.com.br
- Update to 1.1.0:
  - No longer supports Pyhton 2.5
  - Fixed receiving of float table values.
  - Now Supports Python 3 and Python 2.6+ in the same source code.
  - Python 3 related fixes.
* Tue Nov  6 2012 alexandre@exatati.com.br
- Update to 1.0.2:
  - Now supports float values in headers/tables.
* Mon Nov  5 2012 alexandre@exatati.com.br
- Update to 1.0.1:
  - Connection errors does no longer include AttributeError.
  - Fixed problem with using the SSL transport in a non-blocking
    context.
    Fix contributed by Mher Movsisyan.
* Fri Sep 21 2012 alexandre@exatati.com.br
- Update to 0.9.4:
  - Adds support for exchange_bind and exchange_unbind.
    Contributed by Rumyana Neykova
  - Fixed bugs in funtests and demo scripts.
    Contributed by Rumyana Neykova
- Aditional changes from version 0.9.3:
  - Fixed bug that could cause the consumer to crash when reading
    large message payloads asynchronously.
  - Serialization error messages now include the invalid value.
* Fri Aug 24 2012 alexandre@exatati.com.br
- Initial package (0.9.2) for openSUSE.
